from setuptools import setup, find_packages


setup(
    name='yolo_as_one',
    version='0.2',
    license='MIT',
    author="Bramwel Ochieng",
    author_email='lol@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/ochi96/yolo_as_one',
    keywords='yolo installation inferencing'
    # install_requires=[
    #       'scikit-learn',
    #   ]
)




import argparse
from subprocess import call

model_names = ['yolox', 'yolor', 'yolov5']

def parse_args():
    parse = argparse.ArgumentParser()
    parse.add_argument('--model_name', default='None')
    return parse.parse_args()


def install_models(model_name):
    if model_name in model_names:
        call(f"./{model_name}.sh", shell=True)
    else:
        print('model not currently available')
    pass

if __name__=='__main__':
    args = parse_args()
    install_models(args.model_name)
